@@ -28,8 +28,9 @@ class TestEnvDef(BaseModel):
 class TestEnv(BaseModel):
     # Describes a running test setup in which tests (= TestFragments) can be run
     id: int
-    testenv_def_id: int
-    slice_urn: str
+    testenv_def_id: int  # this specifies if the TestEnv is jFed/slice based or something else
+    slice_urn: Optional[str]  # optional during init and if not slice based
+    slice_expire: Optional[datetime]  # optional during init and if not slice based
     auth_token: str  # auth token needed by agent running to auth themselves to perftest-server
     status: TestEnvStatus
 
